==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x0d06+ 2693-0x178b));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x0c42+ 2971-0x17dc));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x04e0+ 6453-0x1e13));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getShadowingModeValue{(my $value=shift (@_));if ((($value 
eq $DesktopMode::ViewOnlyString)or ($value eq $DesktopMode::ViewOnlyValue))){
return ((0x18e6+ 2622-0x2324));}elsif ((($value eq 
$DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue))){
return ((0x0477+ 2375-0x0dbd));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0ca6+ 5101-0x2091));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0a51+ 3221-0x16e5));}return ((0x0107+ 1032-0x050f));}return (
(0x177f+ 303-0x18ad));

==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x009a+ 1009-0x048b));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x0fc8+ 2688-0x1a47));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x07c9+ 334-0x0915));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getShadowingModeValue{(my $value=shift (@_));if ((($value 
eq $DesktopMode::ViewOnlyString)or ($value eq $DesktopMode::ViewOnlyValue))){
return ((0x0b4d+ 930-0x0eef));}elsif ((($value eq $DesktopMode::RestrictedString
)or ($value eq $DesktopMode::RestrictedValue))){return ((0x0f30+ 713-0x11f8));}
elsif ((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ((0x1281+ 2934-0x1df5));}Logger::error 
(
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0bf8+ 1350-0x113d));}return ((0x03c3+ 6602-0x1d8d));}return (
(0x1333+ 4599-0x2529));
